% Pygame-YaGUI documentation master file, created by
% sphinx-quickstart on Thu Feb 23 11:38:45 2023.
% You can adapt this file completely to your liking, but it should at least
% contain the root `toctree` directive.

# Pygame-YaGUI
```{image} pygame-yagui-widgets.png
:alt: Pygame-YaGUI Widgets
:width: 250px
:align: center
```

 **Pygame-YaGUI** is a Yet Another GUI for Pygame based on widgets. This tool was developed to help in the creation of Physics simulation for Science teaching. It has been developed by Alexandre Maciel, Professor at _Universidade Federal do Piaui_.

 [![Twitter URL](https://img.shields.io/twitter/url/https/twitter.com/alxndremaciel.svg?style=social&label=Follow%20%40alxndremaciel)](https://twitter.com/alxndremaciel)
 [![made-with-python](https://img.shields.io/badge/Made%20with-Python-1f425f.svg)](https://www.python.org/)

```{toctree}
:caption: 'Contents:'
:maxdepth: 2

overview
usage
```
